# pacote_processamento_de_imagens

Description. 
The package pacote_processamento_de_imagens is used to:
	Processing
	- Histogram matching
	- Structural similarity
	- Resize image

	Utils:
	- Raed image
	- Save image
	- Plot image
	- Plot result
	- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install pacote_processamento_de_imagens
```

## Usage

```python
from pacote_processamento_de_imagens import processing_images
processing.combination
processing.combinnation
utils.io
utils.plot
```

## Author
Sérgio E. Palmiere

## License
[MIT](https://choosealicense.com/licenses/mit/)